@@ -26,7 +26,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "document/htmlfocusiterator.h"
-#include "document/htmlparser.h"
+#include "document/htmldocument.h"
 #include "dom/core/dom-node.h"
 #include "dom/core/dom-element.h"
 #include "dom/views/dom-abstractview.h"
@@ -950,6 +950,7 @@ html_view_pend_cursor_blink (HtmlView *view)
 					       blink_cb,
 					       view);
 		html_view_set_blink_timeout (view, blink_timeout);
+		html_view_set_cursor_visible (view, 0);
 		show_cursor (view);
  	}
 }
@@ -1903,8 +1904,10 @@ html_view_insert_node (HtmlView *view, DomNode *node)
 			PangoLayout *layout;
 
 			html_view_layout_tree_free (view, view->root);
-			if (view->document && view->document->focus_element)
-				html_document_update_focus_element (view->document, NULL);
+			if (view->document && view->document->focus_element) {
+				g_warning ("Focus element set when inserting toplevel node");
+				view->document->focus_element = NULL;
+			}
 			view->root = new_box;
 
 			layout = html_view_get_layout (view);
@@ -2099,7 +2102,7 @@ html_view_style_updated (HtmlDocument *document, DomNode *node, HtmlStyleChange
 		gtk_widget_style_get (GTK_WIDGET (view),
 				      "focus-line-width", &focus_width,
 				      NULL);
-		html_style_set_outline_width (style, 2 * focus_width);			
+		html_style_set_outline_width (style, focus_width);			
 	}	
 
 	switch (style_change) {
@@ -3090,7 +3093,7 @@ html_view_update_box_style_size (HtmlBox *root, gfloat adjust, gint focus_width,
 			}
 			if (DOM_IS_ELEMENT (root->dom_node) && 
 			    dom_element_is_focusable (DOM_ELEMENT (root->dom_node))) {
-				html_style_set_outline_width (style, 2 * focus_width);			
+				html_style_set_outline_width (style, focus_width);			
 			}	
 		}
 		html_box_set_unrelayouted_up (box);		
@@ -3227,7 +3230,7 @@ html_view_focus_element (HtmlView *view)
 
 				text = HTML_BOX_TEXT (box->children);
 				if (html_view_get_offset_for_box_text (view, text, &offset)) {
-					move_cursor (view, text, offset, FALSE);
+					move_cursor (view, HTML_BOX (text), offset, FALSE);
 					html_view_pend_cursor_blink (view);
 					html_view_check_cursor_blink (view);
 				}
